// http://spoj.pl/problems/ANTTT


#include <stdio.h>
#include <stdlib.h>

typedef struct point {
	int x;
	int y;
} point;

typedef struct line {
	point s, e;
} line;

line lines[1010];

long long int CCW(point A, point B, point C) {
	return (B.x - A.x)*(C.y - A.y) - (B.y - A.y)*(C.x - A.x);
}

// a <= c <= b
int middle(int a, int b, int c) {
	int t;
	
	if ( a > b ) {
		t = a;
		a = b;
		b = t;
	}
	
	if ( a <= c && c <= b ) return 1;
	return 0;
}

int intersect(line a, line b) {
	if ( ( CCW(a.s, a.e, b.s) * CCW(a.s, a.e, b.e) < 0 ) &&
	     ( CCW(b.s, b.e, a.s) * CCW(b.s, b.e, a.e) < 0 ) ) return 1;
		 
	if ( CCW(a.s, a.e, b.s) == 0 && middle(a.s.x, a.e.x, b.s.x) && middle(a.s.y, a.e.y, b.s.y) ) return 1;
	if ( CCW(a.s, a.e, b.e) == 0 && middle(a.s.x, a.e.x, b.e.x) && middle(a.s.y, a.e.y, b.e.y) ) return 1;
	if ( CCW(b.s, b.e, a.s) == 0 && middle(b.s.x, b.e.x, a.s.x) && middle(b.s.y, b.e.y, a.s.y) ) return 1;
	if ( CCW(b.s, b.e, a.e) == 0 && middle(b.s.x, b.e.x, a.e.x) && middle(b.s.y, b.e.y, a.e.y) ) return 1;
	
	return 0;
}

int N;

int e[1010][1010];
int ecnt[1010];

int groups;
int group[1010];

void DFS(int u) {
	int i, next;
	
	if ( group[u] ) return ;
	
	group[u] = groups;
	
	for (i=0; i<ecnt[u]; i++) {
		next = e[u][i];
		
		if ( !group[next] ) {
			DFS(next);
		}
	}
}

int main(void) {
	int i, j, x, y, M, tests;
	
	scanf("%d", &tests);
	
	while(tests--) {
		scanf("%d %d", &N, &M);
		
		for (i=0; i<N; i++) {
			ecnt[i] = 0;
			group[i] = 0;
		}
		
		for (i=0; i<N; i++) {
			scanf("%d %d %d %d", &lines[i].s.x, &lines[i].s.y, &lines[i].e.x, &lines[i].e.y);
		}
		
		for (i=0; i<N; i++) {
			for (j=i+1; j<N; j++) {
				if ( intersect(lines[i], lines[j]) ) {		
					e[ i ][ ecnt[i]++ ] = j;
					e[ j ][ ecnt[j]++ ] = i;
				}
			}
		}
		
		for (i=0; i<N; i++) {
			if ( !group[i] ) {
				groups++;
				
				DFS(i);
			}
		}
		
		for (i=0; i<M; i++) {
			scanf("%d %d", &x, &y);
			x--; y--;
			
			if ( group[x] == group[y] ) {
				printf("YES\n");
			}
			else {
				printf("NO\n");
			}
		}
	}
	
	return 0;
}
