// http://spoj.pl/problems/BSHEEP

#include <stdio.h>
#include <stdlib.h>
#include <math.h>

typedef struct point {
	int x, y, id;
} point;

point lowest;

long long CCW(point A, point B, point C) {
	return (B.x - A.x) * (C.y - A.y) - (B.y - A.y) * (C.x - A.x);
}

int dist(point A, point B) {
	return (B.x - A.x) * (B.x - A.x) + (B.y - A.y) * (B.y - A.y);
}

int compare(const void *a, const void *b) {
	point c = *((point *)a), d = *((point *)b);
	
	if ( CCW(lowest, c, d) > 0 ) {
		return -1;
	}
	if ( CCW(lowest, c, d) < 0 ) {
		return 1;
	}

	//CCW(lowest, c, d) == 0
	if ( dist(lowest, c) < dist(lowest, d) ) {
		return -1;
	}
	if ( dist(lowest, c) > dist(lowest, d) ) {
		return 1;
	}
	
	//τα σημεία ταυτίζονται
	return c.id - d.id;
}


void swap(point *a, point *b) {
	point t;
	
	t = *a;
	*a = *b;
	*b = t;
}

int main(void) {
	int i, tests, N, M;
	double ans;
	point p[100010], hull[100010];
	
	scanf("%d", &tests);
	
	while(tests--) {
		scanf("%d", &N);
		
		ans = 0;
		
		for (i=0; i<N; i++) {
			scanf("%d %d", &p[i].x, &p[i].y);
			p[i].id = i+1;
			
			//1o Βήμα: Εύρεση σημείου με την χαμηλότερη y-συνιστώσα
			if ( i == 0 || p[i].y < lowest.y || (p[i].y == lowest.y && p[i].x < lowest.x ) ) {
				lowest = p[i];
			}
		}
		
		//2o Βήμα: Ταξινόμηση σημείων κατά γωνία
		qsort(p, N, sizeof(point), compare);
		
		//3ο Βήμα: Υπολογισμός convex hull
		M = 0;
		
		for (i=0; i<N; i++) {
			if ( i > 0 && p[i].x == p[i-1].x && p[i].y == p[i-1].y ) continue;
			
			while (M >= 2 && CCW(hull[M-2], hull[M-1], p[i]) <= 0) {
				M--;
			}
			
			hull[M++] = p[i];
		}
		
		//Υπολογισμός περιμέτρου και εκτύπωση αποτελεσμάτων
		for (i=0; i<M; i++) {
			ans += sqrt(dist(hull[i], hull[(i+1)%M]));
		}
		
		printf("%.2lf\n", ans);
		for (i=0; i<M; i++) {
			printf("%d%c", hull[i].id, (i+1==M?'\n':' '));
		}
		if ( tests ) printf("\n");
	}
	
	return 0;
}
