#undef DEBUG

#ifdef DEBUG
#define debug(...) fprintf(stderr, __VA_ARGS__)
#else
#define debug(...) do ; while(0)
#define NDEBUG
#endif

#include <assert.h>
#include <stdio.h>
#include <limits.h>
#include <vector>
#include <queue>
#include <algorithm>

using namespace std;

struct edge { int v, dist; };

bool operator < (const edge & x, const edge & y)
{
  return x.dist > y.dist;
}

#define INF INT_MAX

#define pb push_back

void dijkstra (int N, vector<edge> adj[], int src, int d[])
{
  priority_queue<edge> S;

  for (int i=1; i<=N; i++)
    d[i] = INF;

  S.push((edge) {src, 0});
  while (!S.empty()) {
    edge e = S.top();
    S.pop();
    if (e.dist < d[e.v]) {
      d[e.v] = e.dist;
      for (int j=0; j<adj[e.v].size(); j++)
        S.push((edge) {adj[e.v][j].v, d[e.v] + adj[e.v][j].dist});
    }
  }
}

int main ()
{
  freopen("souvlakia.in", "rt", stdin);
  freopen("souvlakia.out", "wt", stdout);

  int N, M;
  scanf("%d %d", &N, &M);
  vector<edge> adj[N+1];
  for (int i=0; i<M; i++) {
    int a, b, d;
    scanf("%d %d %d\n", &a, &b, &d);
    adj[a].pb((edge) {b, d});
    adj[b].pb((edge) {a, d});
  }
  int A, B, C, L;
  scanf("%d %d %d %d\n", &A, &B, &C, &L);

  int d[3][N+1];
  dijkstra(N, adj, A, d[0]);
  dijkstra(N, adj, B, d[1]);
  dijkstra(N, adj, C, d[2]);

  enum { UNKNOWN, YES, NO } answer[N+1];
  for (int i=1; i<=N; i++)
    answer[i] = UNKNOWN;
  for (int i=0; i<L; i++) {
    int q;
    scanf("%d\n", &q);
    if (answer[q] == UNKNOWN) {
      answer[q] = YES;
      for (int j=1; j<=N; j++)
        if (d[0][j] < d[0][q] && d[1][j] < d[1][q] && d[2][j] < d[2][q]) {
          answer[q] = NO;
          break;
        }
    }
    printf("%s\n", (answer[q] == YES ? "YES" : "NO"));
  }

  return 0;
}
