//http://www.spoj.pl/problems/DOORSPEN/
#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <cstring>
#include <vector>
#include <deque>
#include <list>
#include <set>
#include <map>
#include <stack>
#include <queue>
#include <algorithm>

#define MAXN 2005
#define INF 0x3f3f3f3f
#define LINF ((1LL << 62LL ) - 5LL)
#define pb push_back
#define mp make_pair
#define X first
#define Y second

using namespace std;

typedef long long llint;
typedef pair<llint,llint> pii;
typedef pair<double,double> point;

int dx[8] = {1,0,-1,0,1,-1,-1,1};
int dy[8] = {0,1,0,-1,1,1,-1,-1};

//////////////////////////////////////////////////////////////////////////////////////////////////////////

void Read();
bool Equal ( double a, double b );

pii hull1[MAXN], hull2[MAXN], p[MAXN], d[MAXN], zero;
int D, P, sz1, sz2;

void Init() {
	sz1 = sz2 = 0;
}

bool middle ( pii A, pii B, pii C ) {
	int minx = min ( A.X, B.X );
	int maxx = max ( A.X, B.X );
	int miny = min ( A.Y, B.Y );
	int maxy = max ( A.Y, B.Y );
	return ( minx <= C.X && C.X <= maxx && miny <= C.Y && C.Y <= maxy );
}

llint CCW ( pii A, pii B, pii C ) {
	return (llint)(B.X-A.X)*(llint)(C.Y-A.Y) - (llint)(B.Y-A.Y)*(llint)(C.X-A.X);
}

bool Diff_Sign ( llint a, llint b ) {
	if ( a < 0 && b > 0 ) {
		return true;
	}
	if ( a > 0 && b < 0 ) {
		return true;
	}
	return false;
}

bool Intersect ( pii A, pii B, pii C, pii D ) {
	return ( Diff_Sign(CCW ( A,B,C ) , CCW ( A,B,D ) ) && Diff_Sign (CCW ( C, D, A ) , CCW ( C, D, B ) ) );
}

llint sq ( llint x ) {
	return x*x;
}

llint Dist ( pii A, pii B ) {
	return sq ( A.X-B.X ) + sq ( A.Y-B.Y ); //den exoume logo na to baloume se riza!
}

bool comp ( pii A, pii B ) {
	if ( CCW ( zero, B, A ) < 0 ) {
		return true;
	}
	if ( CCW ( zero, B, A ) > 0 ) {
		return false;
	}
	return Dist (zero,A) < Dist(zero,B);
}

void ConvexHull ( pii A[], int N, pii hull[], int &sz ) {
	int i, minind = 1;

	for ( i=2; i<=N; ++i ) {
		if ( A[i].Y < A[minind].Y || ( A[i].Y == A[minind].Y && A[i].X < A[minind].X ) ) {
			minind = i;
		}
	}

	swap ( A[1], A[minind] );
	zero = A[1];
	sort ( A+2, A+N+1, comp );

	sz = 0;
	
	for ( i=1; i<=N; ++i ) {
		while ( sz >= 2 && CCW ( hull[sz-1], hull[sz], A[i] ) <= 0  ) {
			--sz;
		}
		hull[ ++sz ] = A[i];
	}
}

bool InPolygon ( pii A, pii B[], int N ) {
	int inters=0, i;

	pii inf = mp ( INF, A.Y+1 );
	//Ara to euthigramo tmima exei akra ( A.X, A.Y ), (INF,A.Y+1).
	//Me auto ton tropo, den iparxei alli akeraia sintetagmeni ston Y ektow ap' ta akra.
	//Mas glitonei apo elegxous oriakon periptoseon opou briskoume kombo anti gia akmi, opote de metrietai to intersection!

	/* O perittos elegxos pou tha eprepe na kanoume an ipirxan akeraies sintetagmenes ston Y
	for ( i=1; i<=N; ++i ) {
		if ( CCW ( A, inf, B[i] ) == 0 && A.X <= B[i].X && B[i].X <= inf.X) {
			++inters;
		}
	}
	*/

	for ( i=1; i<=N; ++i ) {
		if ( Intersect ( A, inf, B[i], B[ (i%N) + 1 ] ) ) {
			++inters;
		}
	}

	return inters % 2;
}

bool Boundary ( pii A, pii hull[], int sz ) {
	int i;

	for ( i=1; i<=sz; ++i ) {
		if ( CCW ( hull[i], hull[ (i%sz) + 1 ], A ) == 0 && middle ( hull[i], hull[ (i%sz)+1 ], A ) ) {
			return true;
		}
	}
	
	return false;
}

void Check() {
	int i, j;

	for ( i=1; i<=D; ++i ) {
		if ( InPolygon ( d[i], hull2, sz2 ) || Boundary ( d[i], hull2, sz2 ) ) {
			printf ("It is not possible to separate the two groups of vendors.\n");
			return;
		}
	}

	for ( i=1; i<=P; ++i ) {
		if ( InPolygon ( p[i], hull1, sz1 ) || Boundary ( p[i], hull1, sz1 ) ) {
			printf ("It is not possible to separate the two groups of vendors.\n");
			return;
		}
	}
	
	for ( i=1; i<=sz1; ++i ) {
		for ( j=1; j<=sz2; ++j ) {
			if ( Intersect ( hull1[i], hull1[ (i%sz1) + 1 ], hull2[j], hull2[ (j%sz2) + 1 ] ) ) {
				printf ("It is not possible to separate the two groups of vendors.\n");
				return;
			}
		}
	}

	printf ("It is possible to separate the two groups of vendors.\n");
}

int main ( void ) {
	//freopen ("","r",stdin);
	//freopen ("","w",stdout);

	int t, i;
	for ( t=1;; ++t ) {
		Init();
		Read();
		ConvexHull (d,D,hull1,sz1);
		ConvexHull (p,P,hull2,sz2);
		printf ("Case %d: ", t);
		Check();
		printf ("\n");
	}


	return 0;
}

void Read() {
	llint i, x1, y1, x2, y2;

	scanf ("%d %d", &D, &P);
	if ( D==0 && P==0 ) {
		exit(0);
	}

	for ( i=1; i<=D; ++i ) {
		scanf ("%lld %lld %lld %lld", &x1, &y1, &x2, &y2);
		d[4*(i-1)+1] = mp (x1,y1);
		d[4*(i-1)+2] = mp (x1,y2);
		d[4*(i-1)+3] = mp (x2,y1);
		d[4*(i-1)+4] = mp (x2,y2);
	}
	for ( i=1; i<=P; ++i ) {
		scanf ("%lld %lld %lld %lld", &x1, &y1, &x2, &y2);
		p[4*(i-1)+1] = mp (x1,y1);
		p[4*(i-1)+2] = mp (x1,y2);
		p[4*(i-1)+3] = mp (x2,y1);
		p[4*(i-1)+4] = mp (x2,y2);
	}

	P *= 4;
	D *= 4;
}

bool Equal ( double a, double b ) {
	return fabs (a-b) < 1e-9;
}
