#include <cstdio>
#include <cstdlib>
#include <ctime>
#include <algorithm>
#include <cmath>

#define N 1000
#define X first
#define Y second
#define mp make_pair
#define MAXCOORD 5000
using namespace std;

typedef long long ll;
typedef pair<ll, ll> point;

int sz;
point hull[N+5], p[N+5];

ll CCW ( point A, point B, point C ) {
	return (B.X-A.X)*(C.Y-A.Y)-(B.Y-A.Y)*(C.X-A.X);
}

ll sq ( ll a ) {
	return a*a;
}

ll dist ( point A, point B ) {
	return sq ( A.X-B.X ) + sq ( A.Y-B.Y );
}

double angle ( point A ) {
	A.Y -= hull[1].Y;
	A.X -= hull[1].X;
	
	double ang = atan2 ( (double)A.Y, (double)A.X );
	if ( ang < 0 ) {
		ang += 2*M_PI;
	}
	return ang;
}

bool comp ( point A, point B ) {
	ll a = CCW ( p[1], A, B );
	if ( a != 0 ) {
		return a > 0;
	}
	return dist(p[1],A) < dist(p[1],B);
}

void Read() {
	int i;

	for ( i=1; i<=N; ++i ) {
		p[i] = mp ( (ll)(rand() % MAXCOORD), (ll)(rand() % MAXCOORD) );
	}
}

void Graham() {
	int i, minind=1;
	
	for ( i=2; i<=N; ++i ) {
		if ( p[i].Y < p[minind].Y || ( p[i].Y==p[minind].Y && p[i].X < p[minind].X ) ) {
			minind = i;
		}
	}

	swap ( p[1], p[minind] );
	sort ( p+2, p+N+1, comp );

	for ( i=1; i<=N; ++i ) {
		while ( sz >= 2 && CCW ( hull[ sz-1 ], hull[sz], p[i] ) <= 0 ) {
			--sz;
		}
		hull[ ++sz ] = p[i];
	}
	
	printf ("First point %lld %lld\n", hull[1].X, hull[1].Y );
	for ( i=2; i<=sz; ++i ) {
		printf ("%dth point %lld %lld, angle %lf\n", i, hull[i].X, hull[i].Y, angle(hull[i]) );	
	}
}


bool BruteIn ( point p[], int sz, point A ) {
	int i;

	for ( i=1; i<=sz; ++i ) {
		if ( CCW ( p[i], p[ (i%sz)+1 ], A ) <= 0LL ) {
			return false;
		}
	}
	
	return true;
}

bool LogN ( point A ) {
	double ang = angle ( A );
	int lo, hi, mid;

	lo = 2, hi = sz-1;
	while ( lo < hi ) {
		mid = ( lo+hi+1 ) / 2;
		if ( angle ( hull[mid] ) >= ang ) {
			hi = mid-1;
		}
		else {
			lo = mid;
		}
	}
	
	//return CCW ( hull[lo], hull[lo+1], A ) * CCW ( hull[lo], hull[lo+1], hull[1] ) > 0;
	return CCW ( hull[lo], hull[lo+1], A ) > 0LL && CCW ( hull[sz],hull[1],A ) > 0LL && CCW ( hull[1],hull[2],A ) > 0LL;
}

bool middle ( point A, point B, point C ) {
	ll minx = min ( A.X, B.X );
	ll maxx = max ( A.X, B.X );
	ll miny = min ( A.Y, B.Y );
	ll maxy = max ( A.Y, B.Y );
	return minx <= C.X && C.X <= maxx && miny <= C.Y && C.Y <= maxy;
}

bool Boundary ( point A ) {
	int i;

	for ( i=1; i<=sz; ++i ) {
		if ( CCW ( hull[i], hull[ (i%sz) + 1 ], A ) == 0 && middle ( hull[i], hull[ (i%sz)+1 ], A ) ) {
			return true;
		}
	}
	
	return false;
}

void Simulate() {
	point findit;
	int i;

	for ( i=1; i<=N; ++i ) {
		findit = mp ( rand() % MAXCOORD, rand() % MAXCOORD );
		if ( Boundary( findit ) ) {
			continue;
		}
		if ( BruteIn ( hull, sz, findit ) != LogN ( findit ) ) {
			printf ("An to blepeis auto, kati skatosame sto simeio : %lld %lld\n", findit.X, findit.Y );
		}
	}

	printf ("Telos!\n");
}
int main ( void ) {
	srand(time(NULL));

	Read();
	Graham();
	Simulate();
}
