#undef DEBUG

#ifdef DEBUG
#define debug(...) fprintf(stderr,__VA_ARGS__);
#else
#define debug(...) do ; while(0)
#endif

#include <stddef.h>

using namespace std;

struct trie {
  char letter;
  int depth;
  trie * next[26];
  trie * back;
  trie * quick;

  trie () : letter('$'), depth(0)
  {
    for (int i=0; i<26; i++)
      next[i] = NULL;
    back = NULL;
    quick = NULL;
  }

  trie (char l, trie *t) : letter(l), depth(t->depth+1), back(t)
  {
    for (int i=0; i<26; i++)
      next[i] = NULL;
    int k = depth & (-depth);
    quick = t->parent(k-1);
  }

  trie * parent (int n)
  {
    if (n == 0)
      return this;
    int k = depth & (-depth);
    if (k <= n)
      return quick->parent(n-k);
    else
      return back->parent(n-1);
  }
    
};

#define MAX 1000000

static trie * t;

static trie * state[MAX];
static int stp;

void Init ()
{
  t = new trie();
  stp = 0;
  state[stp] = t;
}

void TypeLetter (char L)
{
  if (t->next[L-'a'] == NULL)
    t->next[L-'a'] = new trie(L, t);
  state[++stp] = t = t->next[L-'a'];
}

void UndoCommands (int U)
{
  t = state[stp-U];
  state[++stp] = t;
}

char GetLetter (int P)
{
  return t->parent(t->depth-P-1)->letter;
}
